# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/Container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import Compression_pb2 as opencannabis_dot_base_dot_Compression__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.crypto.primitives import Keys_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2
from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/Container.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.cryptoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/crypto/Container.proto\x12\x13opencannabis.crypto\x1a#opencannabis/base/Compression.proto\x1a\"opencannabis/content/Content.proto\x1a)opencannabis/crypto/primitives/Keys.proto\x1a.opencannabis/crypto/primitives/Integrity.proto\"\xb4\x01\n\rEncryptedData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x30\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x1e.opencannabis.content.Encoding\x12\x33\n\x0b\x63ompression\x18\x03 \x01(\x0b\x32\x1e.opencannabis.base.Compression\x12.\n\x0b\x66ingerprint\x18\x04 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\"\xc1\x02\n\x12\x45ncryptedContainer\x12\x33\n\x07payload\x18\x01 \x01(\x0b\x32\".opencannabis.crypto.EncryptedData\x12,\n\x06keying\x18\x02 \x01(\x0e\x32\x1c.opencannabis.crypto.KeyType\x12\x39\n\x06vector\x18\x03 \x01(\x0b\x32).opencannabis.crypto.InitializationVector\x12:\n\x03key\x18\x04 \x01(\x0b\x32+.opencannabis.crypto.SymmetricKeyParametersH\x00\x12\x43\n\x07keypair\x18\x05 \x01(\x0b\x32\x30.opencannabis.crypto.AsymmetricKeypairParametersH\x00\x42\x0c\n\nparametersB)\n\x1dio.opencannabis.schema.cryptoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_Compression__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,])




_ENCRYPTEDDATA = _descriptor.Descriptor(
  name='EncryptedData',
  full_name='opencannabis.crypto.EncryptedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='opencannabis.crypto.EncryptedData.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='opencannabis.crypto.EncryptedData.encoding', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='opencannabis.crypto.EncryptedData.compression', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.EncryptedData.fingerprint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=405,
)


_ENCRYPTEDCONTAINER = _descriptor.Descriptor(
  name='EncryptedContainer',
  full_name='opencannabis.crypto.EncryptedContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.crypto.EncryptedContainer.payload', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keying', full_name='opencannabis.crypto.EncryptedContainer.keying', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='opencannabis.crypto.EncryptedContainer.vector', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.crypto.EncryptedContainer.key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keypair', full_name='opencannabis.crypto.EncryptedContainer.keypair', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameters', full_name='opencannabis.crypto.EncryptedContainer.parameters',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=408,
  serialized_end=729,
)

_ENCRYPTEDDATA.fields_by_name['encoding'].enum_type = opencannabis_dot_content_dot_Content__pb2._ENCODING
_ENCRYPTEDDATA.fields_by_name['compression'].message_type = opencannabis_dot_base_dot_Compression__pb2._COMPRESSION
_ENCRYPTEDDATA.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_ENCRYPTEDCONTAINER.fields_by_name['payload'].message_type = _ENCRYPTEDDATA
_ENCRYPTEDCONTAINER.fields_by_name['keying'].enum_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._KEYTYPE
_ENCRYPTEDCONTAINER.fields_by_name['vector'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._INITIALIZATIONVECTOR
_ENCRYPTEDCONTAINER.fields_by_name['key'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._SYMMETRICKEYPARAMETERS
_ENCRYPTEDCONTAINER.fields_by_name['keypair'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._ASYMMETRICKEYPAIRPARAMETERS
_ENCRYPTEDCONTAINER.oneofs_by_name['parameters'].fields.append(
  _ENCRYPTEDCONTAINER.fields_by_name['key'])
_ENCRYPTEDCONTAINER.fields_by_name['key'].containing_oneof = _ENCRYPTEDCONTAINER.oneofs_by_name['parameters']
_ENCRYPTEDCONTAINER.oneofs_by_name['parameters'].fields.append(
  _ENCRYPTEDCONTAINER.fields_by_name['keypair'])
_ENCRYPTEDCONTAINER.fields_by_name['keypair'].containing_oneof = _ENCRYPTEDCONTAINER.oneofs_by_name['parameters']
DESCRIPTOR.message_types_by_name['EncryptedData'] = _ENCRYPTEDDATA
DESCRIPTOR.message_types_by_name['EncryptedContainer'] = _ENCRYPTEDCONTAINER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptedData = _reflection.GeneratedProtocolMessageType('EncryptedData', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDDATA,
  '__module__' : 'opencannabis.crypto.Container_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.EncryptedData)
  })
_sym_db.RegisterMessage(EncryptedData)

EncryptedContainer = _reflection.GeneratedProtocolMessageType('EncryptedContainer', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDCONTAINER,
  '__module__' : 'opencannabis.crypto.Container_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.EncryptedContainer)
  })
_sym_db.RegisterMessage(EncryptedContainer)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Geohash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Geohash.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Geohash.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/geo/Distance.proto\"\x8e\x02\n\x07Geohash\x12G\n\tcomponent\x18\x01 \x03(\tB4\xc2\xb5\x03\x30\x12.Entire string, and substrings, of the geohash.\x12U\n\televation\x18\x02 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB&\xc2\xb5\x03\"\x12 Elevation of this point, if any.\x12\x63\n\x08\x61\x63\x63uracy\x18\x03 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB5\xc2\xb5\x03\x31\x12/Accuracy rating attached to this point, if any.B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,])




_GEOHASH = _descriptor.Descriptor(
  name='Geohash',
  full_name='opencannabis.geo.Geohash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='opencannabis.geo.Geohash.component', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0030\022.Entire string, and substrings, of the geohash.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='opencannabis.geo.Geohash.elevation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Elevation of this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Geohash.accuracy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Accuracy rating attached to this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=383,
)

_GEOHASH.fields_by_name['elevation'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_GEOHASH.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
DESCRIPTOR.message_types_by_name['Geohash'] = _GEOHASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Geohash = _reflection.GeneratedProtocolMessageType('Geohash', (_message.Message,), {
  'DESCRIPTOR' : _GEOHASH,
  '__module__' : 'opencannabis.geo.Geohash_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Geohash)
  })
_sym_db.RegisterMessage(Geohash)


DESCRIPTOR._options = None
_GEOHASH.fields_by_name['component']._options = None
_GEOHASH.fields_by_name['elevation']._options = None
_GEOHASH.fields_by_name['accuracy']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaItem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2
from opencannabis.media import MediaType_pb2 as opencannabis_dot_media_dot_MediaType__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaItem.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\rAttachedMediaH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/media/MediaItem.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\x1a!opencannabis/media/MediaKey.proto\x1a\"opencannabis/media/MediaType.proto\x1a\"opencannabis/base/ProductKey.proto\x1a#opencannabis/temporal/Instant.proto\"\x98\x01\n\x0cMediaSubject\x12\x30\n\x07product\x18\x02 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyH\x00\x12\x11\n\x07partner\x18\x03 \x01(\tH\x00\x12\x12\n\x08location\x18\x04 \x01(\tH\x00\x12\x0f\n\x05\x62rand\x18\x05 \x01(\tH\x00\x12\x10\n\x06global\x18\x06 \x01(\x08H\x00\x42\x0c\n\nattachment\"\xa0\x08\n\x0bMediaUpload\x12\x45\n\x05token\x18\x01 \x01(\tB6\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03,J*Unique ID/token for this upload operation.\x12>\n\toperation\x18\x02 \x01(\tB+\xc2\xb5\x03\'J%Upload operation ID, assigned by GCS.\x12s\n\x05media\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaItemBE\xd2\xb5\x03\x02\x08\x00\xc2\xb5\x03;J9Media item to be attached after this operation completes.\x12S\n\x04mime\x18\x04 \x01(\tBE\xc2\xb5\x03\x41J?Mimetype for the file uploaded as part of this media operation.\x12K\n\x04size\x18\x05 \x01(\x04\x42=\xc2\xb5\x03\x39J7Size, in bytes, of the item uploaded in this operation.\x12K\n\x08\x66inished\x18\x06 \x01(\x08\x42\x39\xc2\xb5\x03\x35J3Whether this upload operation has completed or not.\x12\x32\n\x03md5\x18\x07 \x01(\tB%\xc2\xb5\x03!J\x1fMD5 hash for the data uploaded.\x12\x36\n\x05\x63rc32\x18\x08 \x01(\tB\'\xc2\xb5\x03#J!CRC32 hash for the data uploaded.\x12G\n\x05owner\x18\t \x01(\tB8\xc2\xb5\x03\x34J2User account that initiated this upload operation.\x12\x37\n\x04path\x18\n \x01(\tB)\xc2\xb5\x03%J#Path in GCS to the underlying file.\x12G\n\x06parent\x18\x0b \x01(\tB7\xc2\xb5\x03\x33J1Previous upload version for this same media item.\x12l\n\x07\x63reated\x18\x14 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB;\xc2\xb5\x03\x37J5Timestamp for when this upload operation was created.\x12p\n\tcompleted\x18\x15 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB=\xc2\xb5\x03\x39J7Timestamp for when this upload operation was completed.:\x0f\x8a\xf7\x02\x0b\x08\x02\x12\x07uploads\"\x90\x08\n\tMediaItem\x12`\n\x03key\x18\x01 \x01(\x0b\x32\x1c.opencannabis.media.MediaKeyB5\xc2\xb5\x03\x02\x08\x01\xc2\xb5\x03+J)Key uniquely identifying this media item.\x12]\n\x06status\x18\x02 \x01(\x0e\x32\x1f.opencannabis.media.MediaStatusB,\xc2\xb5\x03(J&Status for this individual media item.\x12T\n\x04type\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaTypeB\'\xc2\xb5\x03#J!Type of media this is describing.\x12\x31\n\x04name\x18\x04 \x01(\tB#\xc2\xb5\x03\x1fJ\x1d\x46riendly name for this media.\x12.\n\x03uri\x18\x05 \x01(\tB!\xc2\xb5\x03\x1dJ\x1b\x41\x62solute URI to this media.\x12Y\n\x0bserving_uri\x18\x06 \x01(\tBD\xc2\xb5\x03@J>Serving URI for this media, if it differs from the origin URI.\x12Z\n\x07privacy\x18\x07 \x01(\x0e\x32 .opencannabis.media.MediaPrivacyB\'\xc2\xb5\x03#J!Privacy mode for this media item.\x12\x62\n\x07\x63reated\x18\x08 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB1\xc2\xb5\x03-J+Timestamp for when this record was created.\x12i\n\x08modified\x18\t \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB7\xc2\xb5\x03\x33J1Timestamp for when this record was last modified.\x12u\n\tpublished\x18\n \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBB\xc2\xb5\x03>J<Timestamp for when this media item was originally published.\x12\x39\n\x05scope\x18\x0b \x01(\tB*\xc2\xb5\x03&J$Ownership scope for this media item.\x12\x42\n\x05token\x18\x0c \x01(\tB3\xc2\xb5\x03/J-Most recent upload token for this media item.:\r\x8a\xf7\x02\t\x08\x02\x12\x05media*D\n\x0bMediaStatus\x12\x0f\n\x0bPROVISIONED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08UPLOADED\x10\x02\x12\t\n\x05READY\x10\x03*<\n\x0cMediaPrivacy\x12\x13\n\x0f\x44\x45\x46\x41ULT_PRIVACY\x10\x00\x12\x0b\n\x07PARTNER\x10\x01\x12\n\n\x06PUBLIC\x10\x02\x42\x37\n\x1cio.opencannabis.schema.mediaB\rAttachedMediaH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaType__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_MEDIASTATUS = _descriptor.EnumDescriptor(
  name='MediaStatus',
  full_name='opencannabis.media.MediaStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROVISIONED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2486,
  serialized_end=2554,
)
_sym_db.RegisterEnumDescriptor(_MEDIASTATUS)

MediaStatus = enum_type_wrapper.EnumTypeWrapper(_MEDIASTATUS)
_MEDIAPRIVACY = _descriptor.EnumDescriptor(
  name='MediaPrivacy',
  full_name='opencannabis.media.MediaPrivacy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_PRIVACY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTNER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2556,
  serialized_end=2616,
)
_sym_db.RegisterEnumDescriptor(_MEDIAPRIVACY)

MediaPrivacy = enum_type_wrapper.EnumTypeWrapper(_MEDIAPRIVACY)
PROVISIONED = 0
PENDING = 1
UPLOADED = 2
READY = 3
DEFAULT_PRIVACY = 0
PARTNER = 1
PUBLIC = 2



_MEDIASUBJECT = _descriptor.Descriptor(
  name='MediaSubject',
  full_name='opencannabis.media.MediaSubject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.media.MediaSubject.product', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.media.MediaSubject.partner', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.media.MediaSubject.location', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brand', full_name='opencannabis.media.MediaSubject.brand', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global', full_name='opencannabis.media.MediaSubject.global', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='attachment', full_name='opencannabis.media.MediaSubject.attachment',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=230,
  serialized_end=382,
)


_MEDIAUPLOAD = _descriptor.Descriptor(
  name='MediaUpload',
  full_name='opencannabis.media.MediaUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='opencannabis.media.MediaUpload.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003,J*Unique ID/token for this upload operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='opencannabis.media.MediaUpload.operation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'J%Upload operation ID, assigned by GCS.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.media.MediaUpload.media', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\322\265\003\002\010\000\302\265\003;J9Media item to be attached after this operation completes.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mime', full_name='opencannabis.media.MediaUpload.mime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003AJ?Mimetype for the file uploaded as part of this media operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='opencannabis.media.MediaUpload.size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7Size, in bytes, of the item uploaded in this operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished', full_name='opencannabis.media.MediaUpload.finished', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0035J3Whether this upload operation has completed or not.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='opencannabis.media.MediaUpload.md5', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003!J\037MD5 hash for the data uploaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc32', full_name='opencannabis.media.MediaUpload.crc32', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!CRC32 hash for the data uploaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='opencannabis.media.MediaUpload.owner', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034J2User account that initiated this upload operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='opencannabis.media.MediaUpload.path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003%J#Path in GCS to the underlying file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='opencannabis.media.MediaUpload.parent', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0033J1Previous upload version for this same media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.media.MediaUpload.created', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0037J5Timestamp for when this upload operation was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='completed', full_name='opencannabis.media.MediaUpload.completed', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7Timestamp for when this upload operation was completed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\013\010\002\022\007uploads',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=1441,
)


_MEDIAITEM = _descriptor.Descriptor(
  name='MediaItem',
  full_name='opencannabis.media.MediaItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.media.MediaItem.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001\302\265\003+J)Key uniquely identifying this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.media.MediaItem.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003(J&Status for this individual media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.media.MediaItem.type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!Type of media this is describing.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.media.MediaItem.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\037J\035Friendly name for this media.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.media.MediaItem.uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\035J\033Absolute URI to this media.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_uri', full_name='opencannabis.media.MediaItem.serving_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@J>Serving URI for this media, if it differs from the origin URI.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy', full_name='opencannabis.media.MediaItem.privacy', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!Privacy mode for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.media.MediaItem.created', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003-J+Timestamp for when this record was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.media.MediaItem.modified', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0033J1Timestamp for when this record was last modified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published', full_name='opencannabis.media.MediaItem.published', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003>J<Timestamp for when this media item was originally published.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='opencannabis.media.MediaItem.scope', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&J$Ownership scope for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='opencannabis.media.MediaItem.token', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/J-Most recent upload token for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\t\010\002\022\005media',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=2484,
)

_MEDIASUBJECT.fields_by_name['product'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['product'])
_MEDIASUBJECT.fields_by_name['product'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['partner'])
_MEDIASUBJECT.fields_by_name['partner'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['location'])
_MEDIASUBJECT.fields_by_name['location'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['brand'])
_MEDIASUBJECT.fields_by_name['brand'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['global'])
_MEDIASUBJECT.fields_by_name['global'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIAUPLOAD.fields_by_name['media'].message_type = _MEDIAITEM
_MEDIAUPLOAD.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAUPLOAD.fields_by_name['completed'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['key'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAKEY
_MEDIAITEM.fields_by_name['status'].enum_type = _MEDIASTATUS
_MEDIAITEM.fields_by_name['type'].message_type = opencannabis_dot_media_dot_MediaType__pb2._MEDIATYPE
_MEDIAITEM.fields_by_name['privacy'].enum_type = _MEDIAPRIVACY
_MEDIAITEM.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['published'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
DESCRIPTOR.message_types_by_name['MediaSubject'] = _MEDIASUBJECT
DESCRIPTOR.message_types_by_name['MediaUpload'] = _MEDIAUPLOAD
DESCRIPTOR.message_types_by_name['MediaItem'] = _MEDIAITEM
DESCRIPTOR.enum_types_by_name['MediaStatus'] = _MEDIASTATUS
DESCRIPTOR.enum_types_by_name['MediaPrivacy'] = _MEDIAPRIVACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaSubject = _reflection.GeneratedProtocolMessageType('MediaSubject', (_message.Message,), {
  'DESCRIPTOR' : _MEDIASUBJECT,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaSubject)
  })
_sym_db.RegisterMessage(MediaSubject)

MediaUpload = _reflection.GeneratedProtocolMessageType('MediaUpload', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAUPLOAD,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaUpload)
  })
_sym_db.RegisterMessage(MediaUpload)

MediaItem = _reflection.GeneratedProtocolMessageType('MediaItem', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAITEM,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaItem)
  })
_sym_db.RegisterMessage(MediaItem)


DESCRIPTOR._options = None
_MEDIAUPLOAD.fields_by_name['token']._options = None
_MEDIAUPLOAD.fields_by_name['operation']._options = None
_MEDIAUPLOAD.fields_by_name['media']._options = None
_MEDIAUPLOAD.fields_by_name['mime']._options = None
_MEDIAUPLOAD.fields_by_name['size']._options = None
_MEDIAUPLOAD.fields_by_name['finished']._options = None
_MEDIAUPLOAD.fields_by_name['md5']._options = None
_MEDIAUPLOAD.fields_by_name['crc32']._options = None
_MEDIAUPLOAD.fields_by_name['owner']._options = None
_MEDIAUPLOAD.fields_by_name['path']._options = None
_MEDIAUPLOAD.fields_by_name['parent']._options = None
_MEDIAUPLOAD.fields_by_name['created']._options = None
_MEDIAUPLOAD.fields_by_name['completed']._options = None
_MEDIAUPLOAD._options = None
_MEDIAITEM.fields_by_name['key']._options = None
_MEDIAITEM.fields_by_name['status']._options = None
_MEDIAITEM.fields_by_name['type']._options = None
_MEDIAITEM.fields_by_name['name']._options = None
_MEDIAITEM.fields_by_name['uri']._options = None
_MEDIAITEM.fields_by_name['serving_uri']._options = None
_MEDIAITEM.fields_by_name['privacy']._options = None
_MEDIAITEM.fields_by_name['created']._options = None
_MEDIAITEM.fields_by_name['modified']._options = None
_MEDIAITEM.fields_by_name['published']._options = None
_MEDIAITEM.fields_by_name['scope']._options = None
_MEDIAITEM.fields_by_name['token']._options = None
_MEDIAITEM._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/labtesting/Terpenes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/labtesting/Terpenes.proto',
  package='opencannabis.structs.labtesting',
  syntax='proto3',
  serialized_options=b'\n-io.opencannabis.schema.product.struct.testingB\020TerpeneCompoundsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/structs/labtesting/Terpenes.proto\x12\x1fopencannabis.structs.labtesting*\xae\x05\n\x07Terpene\x12\x0c\n\x08\x43\x41MPHENE\x10\x00\x12\n\n\x06\x43\x41RENE\x10\x01\x12\x16\n\x12\x42\x45TA_CARYOPHYLLENE\x10\x02\x12\x17\n\x13\x43\x41RYOPHYLLENE_OXIDE\x10\x03\x12\x0e\n\nEUCALYPTOL\x10\x04\x12\x0b\n\x07\x46\x45NCHOL\x10\x05\x12\x12\n\x0e\x41LPHA_HUMULENE\x10\x06\x12\x0c\n\x08LIMONENE\x10\x07\x12\x0c\n\x08LINALOOL\x10\x08\x12\x0b\n\x07MYRCENE\x10\t\x12\x11\n\rALPHA_OCIMENE\x10\n\x12\x10\n\x0c\x42\x45TA_OCIMENE\x10\x0b\x12\x16\n\x12\x41LPHA_PHELLANDRENE\x10\x0c\x12\x10\n\x0c\x41LPHA_PINENE\x10\r\x12\x0f\n\x0b\x42\x45TA_PINENE\x10\x0e\x12\x13\n\x0f\x41LPHA_TERPINEOL\x10\x0f\x12\x13\n\x0f\x41LPHA_TERPININE\x10\x10\x12\x13\n\x0fGAMMA_TERPININE\x10\x11\x12\x0f\n\x0bTERPINOLENE\x10\x12\x12\r\n\tVALENCENE\x10\x13\x12\x0c\n\x08GERANIOL\x10\x14\x12\x10\n\x0cPHELLANDRENE\x10\x15\x12\x0b\n\x07\x42ORNEOL\x10\x16\x12\x0e\n\nISOBORNEOL\x10\x17\x12\r\n\tBISABOLOL\x10\x18\x12\n\n\x06PHYTOL\x10\x19\x12\x0c\n\x08SABINENE\x10\x1a\x12\x0b\n\x07\x43\x41MPHOR\x10\x1b\x12\x0b\n\x07MENTHOL\x10\x1c\x12\x0b\n\x07\x43\x45\x44RENE\x10\x1d\x12\t\n\x05NEROL\x10\x1e\x12\r\n\tNEROLIDOL\x10\x1f\x12\n\n\x06GUAIOL\x10 \x12\x0e\n\nISOPULEGOL\x10!\x12\x13\n\x0fGERANYL_ACETATE\x10\"\x12\n\n\x06\x43YMENE\x10#\x12\x0c\n\x08PULEGONE\x10$\x12\x0b\n\x07\x43INEOLE\x10%\x12\x0c\n\x08\x46\x45NCHONE\x10&\x12\r\n\tTERPINENE\x10\'\x12\x0f\n\x0b\x43ITRONELLOL\x10(\x12\x12\n\x0e\x44\x45LTA_3_CARENE\x10)BK\n-io.opencannabis.schema.product.struct.testingB\x10TerpeneCompoundsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_TERPENE = _descriptor.EnumDescriptor(
  name='Terpene',
  full_name='opencannabis.structs.labtesting.Terpene',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAMPHENE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARENE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_CARYOPHYLLENE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARYOPHYLLENE_OXIDE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EUCALYPTOL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FENCHOL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_HUMULENE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIMONENE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINALOOL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MYRCENE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_OCIMENE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_OCIMENE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_PHELLANDRENE', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_PINENE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_PINENE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_TERPINEOL', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_TERPININE', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAMMA_TERPININE', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERPINOLENE', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALENCENE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GERANIOL', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHELLANDRENE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BORNEOL', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISOBORNEOL', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BISABOLOL', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHYTOL', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SABINENE', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMPHOR', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MENTHOL', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CEDRENE', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEROL', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEROLIDOL', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUAIOL', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISOPULEGOL', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GERANYL_ACETATE', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CYMENE', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULEGONE', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CINEOLE', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FENCHONE', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERPINENE', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITRONELLOL', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELTA_3_CARENE', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=84,
  serialized_end=770,
)
_sym_db.RegisterEnumDescriptor(_TERPENE)

Terpene = enum_type_wrapper.EnumTypeWrapper(_TERPENE)
CAMPHENE = 0
CARENE = 1
BETA_CARYOPHYLLENE = 2
CARYOPHYLLENE_OXIDE = 3
EUCALYPTOL = 4
FENCHOL = 5
ALPHA_HUMULENE = 6
LIMONENE = 7
LINALOOL = 8
MYRCENE = 9
ALPHA_OCIMENE = 10
BETA_OCIMENE = 11
ALPHA_PHELLANDRENE = 12
ALPHA_PINENE = 13
BETA_PINENE = 14
ALPHA_TERPINEOL = 15
ALPHA_TERPININE = 16
GAMMA_TERPININE = 17
TERPINOLENE = 18
VALENCENE = 19
GERANIOL = 20
PHELLANDRENE = 21
BORNEOL = 22
ISOBORNEOL = 23
BISABOLOL = 24
PHYTOL = 25
SABINENE = 26
CAMPHOR = 27
MENTHOL = 28
CEDRENE = 29
NEROL = 30
NEROLIDOL = 31
GUAIOL = 32
ISOPULEGOL = 33
GERANYL_ACETATE = 34
CYMENE = 35
PULEGONE = 36
CINEOLE = 37
FENCHONE = 38
TERPINENE = 39
CITRONELLOL = 40
DELTA_3_CARENE = 41


DESCRIPTOR.enum_types_by_name['Terpene'] = _TERPENE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/contact/Website.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/contact/Website.proto',
  package='opencannabis.contact',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contactB\016ContactWebsiteH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/contact/Website.proto\x12\x14opencannabis.contact\x1a\x19gust/core/datamodel.proto\"\x7f\n\x07Website\x12\'\n\x03uri\x18\x01 \x01(\tB\x1a\xc2\xb5\x03\x16\x12\x14URI for the website.\x12\x35\n\x05title\x18\x02 \x01(\tB&\xc2\xb5\x03\"\x12 Title from the HTML page at URI.\x12\x14\n\x04icon\x18\x03 \x01(\x0c\x42\x06\xca\xb5\x03\x02\x10\x01\x42:\n\x1eio.opencannabis.schema.contactB\x0e\x43ontactWebsiteH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_WEBSITE = _descriptor.Descriptor(
  name='Website',
  full_name='opencannabis.contact.Website',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.contact.Website.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\026\022\024URI for the website.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='opencannabis.contact.Website.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Title from the HTML page at URI.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='opencannabis.contact.Website.icon', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=214,
)

DESCRIPTOR.message_types_by_name['Website'] = _WEBSITE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Website = _reflection.GeneratedProtocolMessageType('Website', (_message.Message,), {
  'DESCRIPTOR' : _WEBSITE,
  '__module__' : 'opencannabis.contact.Website_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.Website)
  })
_sym_db.RegisterMessage(Website)


DESCRIPTOR._options = None
_WEBSITE.fields_by_name['uri']._options = None
_WEBSITE.fields_by_name['title']._options = None
_WEBSITE.fields_by_name['icon']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Name.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Name.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\013NameContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/content/Name.proto\x12\x14opencannabis.content\"(\n\x04Name\x12\x0f\n\x07primary\x18\x01 \x01(\t\x12\x0f\n\x07\x64isplay\x18\x02 \x01(\tB7\n\x1eio.opencannabis.schema.contentB\x0bNameContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)




_NAME = _descriptor.Descriptor(
  name='Name',
  full_name='opencannabis.content.Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='opencannabis.content.Name.primary', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display', full_name='opencannabis.content.Name.display', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Name'] = _NAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Name = _reflection.GeneratedProtocolMessageType('Name', (_message.Message,), {
  'DESCRIPTOR' : _NAME,
  '__module__' : 'opencannabis.content.Name_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Name)
  })
_sym_db.RegisterMessage(Name)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
